Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(192)

Unified Diff: pkg/polymer/lib/builder.dart

Issue 704513004: Update comments about CSP in polymer (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/polymer/lib/deploy.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/polymer/lib/builder.dart
diff --git a/pkg/polymer/lib/builder.dart b/pkg/polymer/lib/builder.dart
index 6a7ae45ae758223ca4ddab1b31f8cdd07f81a19f..1ddefc8cb4517a4a4668d166629e45fc38d25fd5 100644
--- a/pkg/polymer/lib/builder.dart
+++ b/pkg/polymer/lib/builder.dart
@@ -256,8 +256,8 @@ class CommandLineOptions {
/// * `--deploy`: force deploy.
/// * `--no-js`: deploy replaces *.dart scripts with *.dart.js. You can turn
/// this feature off with --no-js, which leaves "packages/browser/dart.js".
/// * `--csp`: replaces *.dart with *.dart.precompiled.js to comply with
/// Content Security Policy restrictions.
/// * `--help`: print documentation for each option and exit.
///
/// Currently not all the flags are used by [lint] or [deploy] above, but they
@@ -293,7 +293,7 @@ CommandLineOptions parseOptions([List<String> args]) {
'leaves "packages/browser/dart.js" to do the replacement at runtime.',
defaultsTo: true)
..addFlag('csp', help:
- 'replaces *.dart with *.dart.precompiled.js to comply with \n'
+ 'extracts inlined JavaScript code to comply with \n'
'Content Security Policy restrictions.')
..addFlag('debug', help:
'run in debug mode. For example, use the debug polyfill \n'
@@ -256,8 +256,8 @@ class CommandLineOptions {
/// * `--no-js`: deploy replaces *.dart scripts with *.dart.js. You can turn
/// this feature off with --no-js, which leaves "packages/browser/dart.js".
-/// * `--csp`: replaces *.dart with *.dart.precompiled.js to comply with
-/// Content Security Policy restrictions.
+/// * `--csp`: extracts inlined JavaScript code to comply with Content
+/// Security Policy restrictions.
/// * `--help`: print documentation for each option and exit.
///
« no previous file with comments | « no previous file | pkg/polymer/lib/deploy.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698